/**
 * 根据目录获取路由名 和 文件引用目录(包含一级目录 二级目录...递归)
 **/
const fs = require('fs');

// 根据文件夹名获取参数
// -id => /:id
// -id$ => /:id?
const getRoute = (filename) => {
  if (filename.indexOf('-') >= 0) {
    const splitAry = filename.split('-');
    return splitAry.reduce((prev, cur, curIndex) => {
      // 1.第一项为路由的具体名称 不处理
      if (!curIndex) {
        return '';
      }
      // 当前项包含$ 说明是可选参数 否是是必填参数
      if (cur.indexOf('$') >= 0) {
        return prev + '/:' + cur.replace('$', '') + '?';
      } else {
        return prev + '/:' + cur;
      }
    }, '');
  }
  // 不带 $ 的处理方式
  return '';
}

let rootPath = '';
const getPathAndRoute = (filename, prevList = []) => {
  if (!rootPath) { rootPath = filename };
  // 1.提取目录下的所有文件+文件夹
  const dirList = fs.readdirSync(filename);
  // 2.是否有index.js文件
  const indexList = dirList.filter(function(item) { return item.match(/index.*s/) });
  if (indexList.length) {
    const rootSplitArray = filename.replace(rootPath, '').split('/');
    const pathSplitArray = filename.replace(rootPath, '').split('/pages/');
    return [{
      route: pathSplitArray[pathSplitArray.length -1].split('-')[0] + getRoute(rootSplitArray[rootSplitArray.length - 1]),
      path: filename
    }]
  }
  // 3.将当前目录下的文件夹遍历处理
  const folderList = dirList.filter(function(item) {
    const curPath = filename + "/" + item;
    const stat = fs.statSync(curPath);
    return stat.isDirectory();
  });
  return folderList.reduce(function(prev, cur) {
    return prev.concat(getPathAndRoute(filename + '/' + cur, prev));
  }, prevList)
}

module.exports = getPathAndRoute;